@@ -135,14 +135,7 @@ protected:
     bool directed = false;
     
     std::vector< VirusPtr<TSeq> > viruses = {};
-    std::vector< epiworld_double > prevalence_virus = {}; ///< Initial prevalence_virus of each virus
-    std::vector< bool > prevalence_virus_as_proportion = {};
-    std::vector< VirusToAgentFun<TSeq> > viruses_dist_funs = {};
-    
     std::vector< ToolPtr<TSeq> > tools = {};
-    std::vector< epiworld_double > prevalence_tool = {};
-    std::vector< bool > prevalence_tool_as_proportion = {};
-    std::vector< ToolToAgentFun<TSeq> > tools_dist_funs = {};
 
     std::vector< Entity<TSeq> > entities = {}; 
     std::vector< Entity<TSeq> > entities_backup = {};
@@ -183,7 +176,7 @@ protected:
 
     void dist_tools();
     void dist_virus();
-    // void dist_entities();
+    void dist_entities();
 
     std::chrono::time_point<std::chrono::steady_clock> time_start;
     std::chrono::time_point<std::chrono::steady_clock> time_end;
@@ -227,7 +220,7 @@ protected:
         Entity<TSeq> * entity_,
         epiworld_fast_int new_state_,
         epiworld_fast_int queue_,
-        ActionFun<TSeq> call_,
+        EventFun<TSeq> call_,
         int idx_agent_,
         int idx_object_
         );
@@ -258,6 +251,7 @@ public:
     
     std::vector<epiworld_double> array_double_tmp;
     std::vector<Virus<TSeq> * > array_virus_tmp;
+    std::vector< int > array_int_tmp;
 
     Model();
     Model(const Model<TSeq> & m);
@@ -337,16 +331,12 @@ public:
      * indicating number of individuals.
      */
     ///@{
-    void add_virus(Virus<TSeq> & v, epiworld_double preval);
-    void add_virus_n(Virus<TSeq> & v, epiworld_fast_uint preval);
-    void add_virus_fun(Virus<TSeq> & v, VirusToAgentFun<TSeq> fun);
-    void add_tool(Tool<TSeq> & t, epiworld_double preval);
-    void add_tool_n(Tool<TSeq> & t, epiworld_fast_uint preval);
-    void add_tool_fun(Tool<TSeq> & t, ToolToAgentFun<TSeq> fun);
+    void add_virus(Virus<TSeq> & v);
+    void add_tool(Tool<TSeq> & t);
     void add_entity(Entity<TSeq> e);
     void rm_virus(size_t virus_pos);
     void rm_tool(size_t tool_pos);
-    void rm_entity(size_t entity_pos);
+    void rm_entity(size_t entity_id);
     ///@}
 
     /**
@@ -360,6 +350,20 @@ public:
      * @param skip How many rows to skip.
      */
     void load_agents_entities_ties(std::string fn, int skip);
+    
+    /**
+     * @brief Associate agents-entities from data
+    */
+    void load_agents_entities_ties(
+        const std::vector<int> & agents_ids,
+        const std::vector<int> & entities_ids
+        );
+
+    void load_agents_entities_ties(
+        const int * agents_id,
+        const int * entities_id,
+        size_t n
+        );
 
     /**
      * @name Accessing population of the model
@@ -391,6 +395,8 @@ public:
 
     std::vector< Agent<TSeq> > & get_agents(); ///< Returns a reference to the vector of agents.
 
+    Agent<TSeq> & get_agent(size_t i);
+
     std::vector< epiworld_fast_uint > get_agents_states() const; ///< Returns a vector with the states of the agents.
 
     std::vector< Viruses_const<TSeq> > get_agents_viruses() const; ///< Returns a const vector with the viruses of the agents.
@@ -399,6 +405,8 @@ public:
 
     std::vector< Entity<TSeq> > & get_entities();
 
+    Entity<TSeq> & get_entity(size_t entity_id, int * entity_pos = nullptr);
+
     Model<TSeq> & agents_smallworld(
         epiworld_fast_uint n = 1000,
         epiworld_fast_uint k = 5,
@@ -525,8 +533,6 @@ public:
     virtual void reset();
     const Model<TSeq> & print(bool lite = false) const;
 
-    Model<TSeq> && clone() const;
-
     /**
      * @name Manage state (states) in the model
      * 
@@ -685,8 +691,6 @@ public:
     ///@}
 
     const std::vector< VirusPtr<TSeq> > & get_viruses() const;
-    const std::vector< epiworld_double > & get_prevalence_virus() const;
-    const std::vector< bool > & get_prevalence_virus_as_proportion() const;
     const std::vector< ToolPtr<TSeq> > & get_tools() const;
     Virus<TSeq> & get_virus(size_t id);
     Tool<TSeq> & get_tool(size_t id);
