@@ -4,18 +4,24 @@
 template<typename TSeq = EPI_DEFAULT_TSEQ>
 class ModelSIRCONN : public epiworld::Model<TSeq>
 {
+
 private:
+
+    std::vector< epiworld::Agent<TSeq> * > infected;
+    void update_infected();
+
+public:
+
     static const int SUSCEPTIBLE = 0;
     static const int INFECTED    = 1;
     static const int RECOVERED   = 2;
 
-public:
-
+    
     ModelSIRCONN() {};
 
     ModelSIRCONN(
         ModelSIRCONN<TSeq> & model,
-        std::string vname,
+        const std::string & vname,
         epiworld_fast_uint n,
         epiworld_double prevalence,
         epiworld_double contact_rate,
@@ -24,7 +30,7 @@ public:
     );
 
     ModelSIRCONN(
-        std::string vname,
+        const std::string & vname,
         epiworld_fast_uint n,
         epiworld_double prevalence,
         epiworld_double contact_rate,
@@ -51,9 +57,43 @@ public:
         std::vector< int > queue_ = {}
     );
 
+    /**
+     * @brief Get the infected individuals
+     * @return std::vector< epiworld::Agent<TSeq> * > 
+     */
+    size_t get_n_infected() const
+    {
+        return infected.size();
+    }
+
 
 };
 
+template<typename TSeq>
+inline void ModelSIRCONN<TSeq>::update_infected()
+{
+
+    infected.clear();
+    infected.reserve(this->size());
+
+    for (auto & p : this->get_agents())
+    {
+        if (p.get_state() == ModelSIRCONN<TSeq>::INFECTED)
+        {
+            infected.push_back(&p);
+        }
+    }
+
+    Model<TSeq>::set_rand_binom(
+        this->get_n_infected(),
+        static_cast<double>(Model<TSeq>::par("Contact rate"))/
+            static_cast<double>(Model<TSeq>::size())
+    );
+
+    return;
+
+}
+
 template<typename TSeq>
 inline ModelSIRCONN<TSeq> & ModelSIRCONN<TSeq>::run(
     epiworld_fast_uint ndays,
@@ -71,6 +111,9 @@ inline void ModelSIRCONN<TSeq>::reset()
 {
 
     Model<TSeq>::reset();
+
+    this->update_infected();
+
     return;
 
 }
@@ -100,7 +143,7 @@ inline Model<TSeq> * ModelSIRCONN<TSeq>::clone_ptr()
 template<typename TSeq>
 inline ModelSIRCONN<TSeq>::ModelSIRCONN(
     ModelSIRCONN<TSeq> & model,
-    std::string vname,
+    const std::string & vname,
     epiworld_fast_uint n,
     epiworld_double prevalence,
     epiworld_double contact_rate,
@@ -115,26 +158,21 @@ inline ModelSIRCONN<TSeq>::ModelSIRCONN(
         ) -> void
         {
 
-            // Sampling how many individuals
-            m->set_rand_binom(
-                m->size(),
-                static_cast<double>(
-                    m->par("Contact rate"))/
-                    static_cast<double>(m->size())
-            );
-
             int ndraw = m->rbinom();
 
             if (ndraw == 0)
                 return;
 
+            ModelSIRCONN<TSeq> * model = dynamic_cast<ModelSIRCONN<TSeq> *>(m);
+            size_t ninfected = model->get_n_infected();
+
             // Drawing from the set
             int nviruses_tmp = 0;
             for (int i = 0; i < ndraw; ++i)
             {
                 // Now selecting who is transmitting the disease
                 int which = static_cast<int>(
-                    std::floor(m->size() * m->runif())
+                    std::floor(ninfected * m->runif())
                 );
 
                 /* There is a bug in which runif() returns 1.0. It is rare, but
@@ -144,39 +182,35 @@ inline ModelSIRCONN<TSeq>::ModelSIRCONN(
                  * https://gcc.gnu.org/bugzilla/show_bug.cgi?id=63176
                  * 
                  */
-                if (which == static_cast<int>(m->size()))
+                if (which == static_cast<int>(ninfected))
                     --which;
 
+                epiworld::Agent<TSeq> & neighbor = *model->infected[which];
+
                 // Can't sample itself
-                if (which == static_cast<int>(p->get_id()))
+                if (neighbor.get_id() == p->get_id())
                     continue;
 
-                // If the neighbor is infected, then proceed
-                auto & neighbor = m->get_agents()[which];
-                if (neighbor.get_state() == ModelSIRCONN<TSeq>::INFECTED)
-                {
+                // The neighbor is infected because it is on the list!
+                if (neighbor.get_virus() == nullptr)
+                    continue;
 
-                    if (neighbor.get_virus() == nullptr)
-                        continue;
+                auto & v = neighbor.get_virus();
 
-                    auto & v = neighbor.get_virus();
-
-                    #ifdef EPI_DEBUG
-                    if (nviruses_tmp >= static_cast<int>(m->array_virus_tmp.size()))
-                        throw std::logic_error("Trying to add an extra element to a temporal array outside of the range.");
-                    #endif
-                        
-                    /* And it is a function of susceptibility_reduction as well */ 
-                    m->array_double_tmp[nviruses_tmp] =
-                        (1.0 - p->get_susceptibility_reduction(v, m)) * 
-                        v->get_prob_infecting(m) * 
-                        (1.0 - neighbor.get_transmission_reduction(v, m)) 
-                        ; 
-                
-                    m->array_virus_tmp[nviruses_tmp++] = &(*v);
-                      
-
-                }
+                #ifdef EPI_DEBUG
+                if (nviruses_tmp >= static_cast<int>(m->array_virus_tmp.size()))
+                    throw std::logic_error("Trying to add an extra element to a temporal array outside of the range.");
+                #endif
+                    
+                /* And it is a function of susceptibility_reduction as well */ 
+                m->array_double_tmp[nviruses_tmp] =
+                    (1.0 - p->get_susceptibility_reduction(v, m)) * 
+                    v->get_prob_infecting(m) * 
+                    (1.0 - neighbor.get_transmission_reduction(v, m)) 
+                    ; 
+            
+                m->array_virus_tmp[nviruses_tmp++] = &(*v);
+                 
             }
 
             // No virus to compute
@@ -258,14 +292,25 @@ inline ModelSIRCONN<TSeq>::ModelSIRCONN(
     model.add_param(transmission_rate, "Transmission rate");
     model.add_param(recovery_rate, "Recovery rate");
     // model.add_param(prob_reinfection, "Prob. Reinfection");
+
+    // Adding update function
+    epiworld::GlobalFun<TSeq> update = [](epiworld::Model<TSeq> * m) -> void
+    {
+        ModelSIRCONN<TSeq> * model = dynamic_cast<ModelSIRCONN<TSeq> *>(m);
+        model->update_infected();
+        
+        return;
+    };
+
+    model.add_globalevent(update, "Update infected individuals");
     
     // Preparing the virus -------------------------------------------
-    epiworld::Virus<TSeq> virus(vname);
+    epiworld::Virus<TSeq> virus(vname, prevalence, true);
     virus.set_state(1, 2, 2);
     virus.set_prob_infecting(&model("Transmission rate"));
     virus.set_prob_recovery(&model("Recovery rate"));
 
-    model.add_virus(virus, prevalence);
+    model.add_virus(virus);
 
     model.queuing_off(); // No queuing need
 
@@ -279,7 +324,7 @@ inline ModelSIRCONN<TSeq>::ModelSIRCONN(
 
 template<typename TSeq>
 inline ModelSIRCONN<TSeq>::ModelSIRCONN(
-    std::string vname,
+    const std::string & vname,
     epiworld_fast_uint n,
     epiworld_double prevalence,
     epiworld_double contact_rate,
